/* "$Id: xdeskcal.c,v 1.11 2005/06/09 10:12:27 jjf Exp $" */

/*
  This file is part of xdeskcal.
  Copyright  2005 J Farlow, jjf1125@earthlink.net.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <stdio.h>
#include <stdlib.h>
#include <X11/Intrinsic.h>
#include <X11/Xaw/MenuButton.h>
#include <X11/Xaw/Command.h>
#include <X11/StringDefs.h>

extern XtResource *resources;
extern WidgetClass calendarWidgetClass;

static XrmOptionDescRec options[] = {
  {"-month", "*xdeskcal*month", XrmoptionSepArg,NULL},
  {"-year", "*xdeskcal*year", XrmoptionSepArg,NULL},
  {"-nday", "*xdeskcal*nohighlight", XrmoptionNoArg,"t"},
  {"-nshape", "*xdeskcal*shapeWindow", XrmoptionNoArg, "t"},
};

static char app_name[255];
Atom wm_delete_window;

void exit_handler (Widget, XtPointer, XEvent *, Boolean *);
int parse_args (Arg *, int *, char **);
void usage (void);

int main (int argc, char **argv) {

    XtAppContext app_context;
    Widget toplevel, w;
    Arg *Args;
    int n_Args;
    
    Args = (Arg *) calloc (argc, sizeof (Arg));

    n_Args = parse_args (Args, &argc, argv);

    toplevel = XtAppInitialize (&app_context, "Calendar", 
 				options, XtNumber(options), &argc, argv,
 				NULL, Args, n_Args);

    if (argc != 1) 
      usage ();

    w = XtCreateManagedWidget (app_name, calendarWidgetClass, toplevel, 
			       Args, n_Args);

    XtRealizeWidget (toplevel);

    wm_delete_window = XInternAtom (XtDisplay (toplevel),
 				    "WM_DELETE_WINDOW", False);
    XSetWMProtocols (XtDisplay (toplevel), XtWindow (toplevel),
  		     &wm_delete_window, 1);

    XtAddEventHandler (toplevel, ClientMessage, True, exit_handler, 
		       NULL);

    XtAppMainLoop(app_context);

    return (0);
}

void exit_handler (Widget w, XtPointer data, XEvent *e, Boolean *dispatch) {
  if(e->xclient.data.l[0] == wm_delete_window)
    exit (0);
}

int parse_args (Arg *Args, int *c, char **a) {

  int i, n_Args = 0;

  strcpy (app_name, a[0]);

  for (i = 1; i < *c; i++) {
    if (!strncmp (a[i], "-month", strlen (a[i]))) {
      XtSetArg (Args[n_Args], "month", atoi(&a[i+1][0]));
      i++;  n_Args++;
    }
    if (!strncmp (a[i], "-year", strlen (a[i]))) {
      XtSetArg (Args[n_Args], "year", atoi(&a[i+1][0]));
       i++;  n_Args++;
    }
    if (!strncmp (a[i], "-nday", strlen (a[i]))) {
      XtSetArg (Args[n_Args], "nohighlight", True);
        n_Args++;
    }
    if (!strncmp (a[i], "-nshape", strlen (a[i]))) {
      XtSetArg (Args[n_Args], "shapeWindow", False);
      n_Args++;
    }
  }

  return n_Args;
  
}

void usage (void) {
  printf ("Usage: %s [-h] | [-geometry <w>x<h>+<x>+<y>] [-font <fontname>] [-bg <color>] [-fg <color>] [-month <n>] [-year <n>] [-nday] [-nshape]\n",
	   app_name);
  exit (1);
}


